@@ -5,6 +5,7 @@
 #include <QListView>
 #include <QStyledItemDelegate>
 #include "googlereader.h"
+#include "contentwindow.h"
 
 class EntriesWindow : public QMainWindow {
 	Q_OBJECT
@@ -18,12 +19,16 @@ class EntriesWindow : public QMainWindow {
 		void markRead();
 		void entriesUpdated();
 		void entrySelected(const QModelIndex &);
+		void showNextEntry();
+		void showPrevEntry();
 
 	private:
 		QListView *list;
 		QAction *show_all;
 		QAction *show_updated;
 		Feed *feed;
+		int current_row;
+		ContentWindow *content;
 };
 
 class EntryListModel : public QAbstractListModel {
